==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiCore/QLibrary_shell.h <==
#ifndef QLIBRARY_SHELL_H
#define QLIBRARY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtcore-config.h>
#if QT_CONFIG(library)
#include <QtCore/qlibrary.h>
#endif //QT_CONFIG(library)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(library)

class QLibrary_shell : public QLibrary, public QtJambiShellInterface
{
public:
    QLibrary_shell(QObject* parent0 = nullptr);
    QLibrary_shell(const QString& fileName0, QObject* parent1 = nullptr);
    QLibrary_shell(const QString& fileName0, const QString& version1, QObject* parent2 = nullptr);
    QLibrary_shell(const QString& fileName0, int verNum1, QObject* parent2 = nullptr);
    ~QLibrary_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QLibrary_access : public QLibrary
{
};

#endif // QT_CONFIG(library)
#endif // QLIBRARY_SHELL_H

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiCore/QLibrary_shell.h <==
#ifndef QLIBRARY_SHELL_H
#define QLIBRARY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtcore-config.h>
#if QT_CONFIG(library)
#include <QtCore/qlibrary.h>
#endif //QT_CONFIG(library)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(library)

class QLibrary_shell : public QLibrary, public QtJambiShellInterface
{
public:
    QLibrary_shell(QObject* parent0 = nullptr);
    QLibrary_shell(const QString& fileName0, QObject* parent1 = nullptr);
    QLibrary_shell(const QString& fileName0, const QString& version1, QObject* parent2 = nullptr);
    QLibrary_shell(const QString& fileName0, int verNum1, QObject* parent2 = nullptr);
    ~QLibrary_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QLibrary_mshell;
    friend class QLibrary_oshell;
};


class QLibrary_mshell : public QLibrary_shell
{
public:
    using QLibrary_shell::QLibrary_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QLibrary_oshell : public QLibrary_mshell
{
public:
    using QLibrary_mshell::QLibrary_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QLibrary_access : public QLibrary
{
};

#endif // QT_CONFIG(library)
#endif // QLIBRARY_SHELL_H
